rig library

Alias: rig lib

Manage package libraries [alias: lib] (experimental)

rig supports multiple user package libraries. The usual user library is called “main”.

Each subcommand operates on the default R version, unless you select another installed R version with --r-version.

User libraries are implemented at the user level, no administrator or root password is needed to add, set or delete them. If you delete an R installation, the user package libraries and their configurations are kept for all users on the system.

rig library is currently experimental, and might change in future versions. Feedback is appreciated.

Subcommands

add
Add a new library
default
Set the default library
list
List libraries (alias: ls)
rm
Remove a library

rig library add

Add a new user package library for the current R version.

The new library is created empty. Adding a library does not change the default library; use rig library default to switch to it. No administrator rights are needed.

Use --r-version to add a library for another installed R version, instead of the default one.

Usage

rig library add [OPTIONS] <lib-name>

Arguments

<lib-name>
name of new library

Options

--admin
Run in admin mode (overrides RIG_MODE and config)
-h, --help
Print help (see a summary with ‘-h’)
--no-cache
Do not read or write rig’s cache (overrides RIG_NO_CACHE and config)
-r, --r-version <r-version>
R version to operate on, instead of the default
--user
Run in user mode (overrides RIG_MODE and config)

rig library default

Show or set the default package library for the current R version.

Call without arguments to print the current default library. Call with a library name to make it the default. New R sessions of the current R version will then use that library.

Use --r-version to show or set the default library of another installed R version, instead of the default one.

Usage

rig library default [OPTIONS] [lib-name]

Arguments

[lib-name]
library name to set as default

Options

--admin
Run in admin mode (overrides RIG_MODE and config)
-h, --help
Print help (see a summary with ‘-h’)
--json
JSON output
--no-cache
Do not read or write rig’s cache (overrides RIG_NO_CACHE and config)
-r, --r-version <r-version>
R version to operate on, instead of the default
--user
Run in user mode (overrides RIG_MODE and config)

rig library list

Alias: rig library ls

List the package libraries of the current R version [alias: ls].

The default library is marked. See rig library for an overview of user package libraries.

Use --r-version to list the libraries of another installed R version, instead of the default one.

Usage

rig library list [OPTIONS]

Options

--admin
Run in admin mode (overrides RIG_MODE and config)
-h, --help
Print help (see a summary with ‘-h’)
--json
JSON output
--no-cache
Do not read or write rig’s cache (overrides RIG_NO_CACHE and config)
-r, --r-version <r-version>
R version to operate on, instead of the default
--user
Run in user mode (overrides RIG_MODE and config)

rig library rm

Remove a user package library of the current R version, including all packages installed in it.

You cannot remove the current default library, and you cannot remove the main library. Switch to another library with rig library default first if needed.

Use --r-version to remove a library of another installed R version, instead of the default one.

Usage

rig library rm [OPTIONS] <lib-name>

Arguments

<lib-name>
name of library to remove

Options

--admin
Run in admin mode (overrides RIG_MODE and config)
-h, --help
Print help (see a summary with ‘-h’)
--no-cache
Do not read or write rig’s cache (overrides RIG_NO_CACHE and config)
-r, --r-version <r-version>
R version to operate on, instead of the default
--user
Run in user mode (overrides RIG_MODE and config)