rig list

Alias: rig ls

List installed R versions. It does not check if they are working properly.

rig ls is an alias.

Usage

rig list [OPTIONS]

Options

--admin
Run in admin mode (overrides RIG_MODE and config)
-h, --help
Print help (see a summary with ‘-h’)
--json
JSON output
--no-cache
Do not read or write rig’s cache (overrides RIG_NO_CACHE and config)
--plain
plain output, only the version names, one per line
--user
Run in user mode (overrides RIG_MODE and config)