rig rm

Aliases: rig del, rig remove, rig delete

Remove an R installation. It keeps the users’ package libraries.

In user mode no administrator rights are needed. In admin mode you need an administrator account to run this command or use sudo on Unix, otherwise rig will ask for your password.

Usage

rig rm [OPTIONS] [version]...

Arguments

[version]...
versions to remove

Options

--admin
Run in admin mode (overrides RIG_MODE and config)
-h, --help
Print help (see a summary with ‘-h’)
--no-cache
Do not read or write rig’s cache (overrides RIG_NO_CACHE and config)
--user
Run in user mode (overrides RIG_MODE and config)