rig available
List R versions available to install.
By default some releases are omitted from the output:
- Versions older than R 3.0.0 are omitted. The installation of these might not work at all.
- Only the latest release is shown for each minor version. E.g. R 4.2.3 is listed, but other R 4.2.x versions are not. Use
--allto list all versions.
Use --json to return the output in JSON. JSON output includes the full time stamp (if available) and the download URL as well.
With the --list-distros flag it lists supported Linux distributions.
With the --list-rtools-versions flag it lists supported Rtools versions. Rtools contains tools to build R and R packages on Windows. Use --all to list all Rtools versions, even very old ones.
Usage
rig available [OPTIONS]
Options
--admin- Run in admin mode (overrides RIG_MODE and config)
--all- List all available versions.
-a, --arch <arch>- Use this architecture, instead of auto-detecting it.
-h, --help- Print help (see a summary with ‘-h’)
--json- JSON output
--list-distros- List supported Linux distributions instead of R versions.
--list-rtools-versions- List available Rtools versions instead of R versions.
--platform <platform>- Use this platform, instead of auto-detecting it.
--user- Run in user mode (overrides RIG_MODE and config)