rig config
Manage the rig configuration file.
rig reads a number of settings from a configuration file, e.g. the installation mode (user or admin), the quick-link directory (binary-dir) and the R installation root (r-install-dir). Most settings can also be overridden with environment variables.
rig config config-file-path prints the path to the config file. rig config list lists the names of all configuration entries. rig config get prints the value of a configuration entry. rig config set sets a configuration entry.
Subcommands
config-file-path- Print the path to the rig config file
get- Get a config entry
list- List the names of all config entries
set- Set a config entry
rig config config-file-path
Print the full path to the rig configuration file.
The file might not exist yet; rig creates it when you first set an entry with rig config set.
Usage
rig config config-file-path [OPTIONS]
Options
--admin- Run in admin mode (overrides RIG_MODE and config)
-h, --help- Print help (see a summary with ‘-h’)
--user- Run in user mode (overrides RIG_MODE and config)
rig config get
Print the value of a rig configuration entry.
Configuration keys are listed by rig config list.
Usage
rig config get [OPTIONS] <key>
Arguments
<key>- config key to get
Options
--admin- Run in admin mode (overrides RIG_MODE and config)
-h, --help- Print help (see a summary with ‘-h’)
--json- JSON output
--user- Run in user mode (overrides RIG_MODE and config)
rig config list
List the names of all rig configuration entries.
Use rig config get <key> to see the value of an entry, and rig config set <key>=<value> to change it.
Usage
rig config list [OPTIONS]
Options
--admin- Run in admin mode (overrides RIG_MODE and config)
-h, --help- Print help (see a summary with ‘-h’)
--json- JSON output
--user- Run in user mode (overrides RIG_MODE and config)
rig config set
Set a rig configuration entry.
The argument is a key=value pair, e.g. rig config set mode=user. The configuration file is created if it does not exist yet. Use rig config list to see the available keys.
Usage
rig config set [OPTIONS] <keyvalue>
Arguments
<keyvalue>- key=value pair to set
Options
--admin- Run in admin mode (overrides RIG_MODE and config)
-h, --help- Print help (see a summary with ‘-h’)
--user- Run in user mode (overrides RIG_MODE and config)