rig resolve
Resolve R versions. Checks the version number of an R version (e.g. release, devel, etc.), and looks up the URL of the installer for it, if an installer is available.
It prints the R version number, and after a space the URL of the installer. If no installer is available for this R version and the current platform, the URL is NA.
An R version can be specified in various ways:
rig resolve develis the latest available development version,rig resolve nextis the next (patched, alpha, beta, etc.) version,rig resolve releaseis the latest release.rig resolve x.y.zis a specific version.rig resolve x.yis the latest release within thex.yminor branch.rig resolve oldrel/nis the latest release within thenth previous minor branch (oldrelis the same asoldrel/1).
Usage
rig resolve [OPTIONS] <str>
Arguments
<str>- symbolic version string to resolve
Options
--admin- Run in admin mode (overrides RIG_MODE and config)
-a, --arch <arch>- Use this architecture, instead of auto-detecting it.
-h, --help- Print help (see a summary with ‘-h’)
--json- JSON output
--platform <platform>- Use this platform, instead of auto-detecting it.
--user- Run in user mode (overrides RIG_MODE and config)
Examples
# Latest development snapshot
rig resolve devel# Latest release (that has an installer available)
rig resolve release# URL for a specific version
rig resolve 4.1.2# Latest version within a minor branch
rig resolve 4.1