rig rm
Remove an R installation. It keeps the users’ package libraries.
In user mode no administrator rights are needed. In admin mode you need an administrator account to run this command or use sudo on Unix, otherwise rig will ask for your password.
Usage
rig rm [OPTIONS] [version]...
Arguments
[version]...- versions to remove
Options
--admin- Run in admin mode (overrides RIG_MODE and config)
--all- remove all versions (TODO)
-h, --help- Print help (see a summary with ‘-h’)
--user- Run in user mode (overrides RIG_MODE and config)