rig sysreqs
macOS only
Manage system libraries and tools. This currently includes a very restricted set of tools, that are needed for running R CMD check. Run rig sysreqs list for a complete list.
Subcommands
rig sysreqs add
Install a system library or tool that R packages need to build or run (experimental, macOS only).
Specify one or more tool names; see rig sysreqs list for the available ones. Use --arch to install for a specific architecture; by default the native architecture is used.
Usage
rig sysreqs add [OPTIONS] <name>...
Arguments
<name>...- system tool to install
Options
--admin- Run in admin mode (overrides RIG_MODE and config)
-a, --arch <arch>-
Architecture to install for
[default: ]
[possible values: arm64, x86_64] -h, --help- Print help (see a summary with ‘-h’)
--user- Run in user mode (overrides RIG_MODE and config)
rig sysreqs info
Show information about a system library or tool (experimental, macOS only).
Prints details of the named tool, e.g. its version and whether it is installed. Use rig sysreqs list to see the available tool names.
Usage
rig sysreqs info [OPTIONS] <name>
Arguments
<name>- system tool to show
Options
--admin- Run in admin mode (overrides RIG_MODE and config)
-h, --help- Print help (see a summary with ‘-h’)
--json- JSON output
--user- Run in user mode (overrides RIG_MODE and config)
rig sysreqs list
List the system libraries and tools that rig can install (experimental, macOS only).
See rig sysreqs info <name> for details about a specific tool, and rig sysreqs add <name> to install one.
Usage
rig sysreqs list [OPTIONS]
Options
--admin- Run in admin mode (overrides RIG_MODE and config)
-h, --help- Print help (see a summary with ‘-h’)
--json- JSON output
--user- Run in user mode (overrides RIG_MODE and config)